package
Version:
v0.0.0-...-14857c7
Opens a new window with list of versions in this module.
Published: Nov 15, 2021
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Book struct {
Id int `json:id`
Title string `json:title`
Author string `json:author`
Description string `json:description`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.